@@ -3,19 +3,21 @@ package BioX::Workflow::Command::run;
 use v5.10;
 use MooseX::App::Command;
 
+use File::Path qw(make_path);
+
 extends 'BioX::Workflow::Command';
-use BioX::Workflow::Command::Utils::Traits qw(ArrayRefOfStrs);
-use BioX::Workflow::Command::run::Utils::Directives;
+use BioSAILs::Utils::Traits qw(ArrayRefOfStrs);
+use BioX::Workflow::Command::run::Rules::Directives;
 
 with 'BioX::Workflow::Command::run::Utils::Samples';
 with 'BioX::Workflow::Command::run::Utils::Attributes';
-with 'BioX::Workflow::Command::run::Utils::Rules';
+with 'BioX::Workflow::Command::run::Rules::Rules';
 with 'BioX::Workflow::Command::run::Utils::WriteMeta';
 with 'BioX::Workflow::Command::run::Utils::Files::TrackChanges';
 with 'BioX::Workflow::Command::run::Utils::Files::ResolveDeps';
-with 'BioX::Workflow::Command::Utils::Log';
 with 'BioX::Workflow::Command::Utils::Files';
-with 'BioX::Workflow::Command::Utils::Plugin';
+with 'BioSAILs::Utils::Files::CacheDir';
+with 'BioSAILs::Utils::CacheUtils';
 
 command_short_description 'Run your workflow';
 command_long_description
@@ -23,11 +25,11 @@ command_long_description
 
 =head1 BioX::Workflow::Command::run
 
-This is the main class of the `biox-workflow.pl run` command.
+  biox run -h
+  biox run -w variant_calling.yml
 
 =cut
 
-
 =head2 Attributes
 
 =cut
@@ -39,12 +41,14 @@ This is the main class of the `biox-workflow.pl run` command.
 sub execute {
     my $self = shift;
 
-    $self->app_log->info('Printing out file info for '.$self->workflow);
-    $self->print_opts;
-    if(! $self->load_yaml_workflow){
-      $self->app_log->warn('Exiting now.');
-      return;
+    if ( !$self->load_yaml_workflow ) {
+        $self->app_log->warn('Exiting now.');
+        return;
     }
+
+    $self->print_opts;
+
+    $self->app_log->info("Your cached workflow is available at\n\t".$self->cached_workflow."\n");
     $self->apply_global_attributes;
     $self->get_global_keys;
     $self->get_samples;
@@ -54,7 +58,17 @@ sub execute {
     $self->iterate_rules;
 }
 
+
+before 'BUILD' => sub {
+    my $self = shift;
+
+    make_path( $self->cache_dir );
+    make_path( File::Spec->catdir( $self->cache_dir, '.biox-cache', 'logs' ) );
+    make_path( File::Spec->catdir( $self->cache_dir, '.biox-cache', 'workflows' ) );
+};
+
 no Moose;
+
 __PACKAGE__->meta->make_immutable;
 
 1;
